==> msxpertsuite_3.7.0.orig.tar.gz: msxpertsuite-3.7.0/massxpert/gui/MzLabMassBasedActionsDlg.hpp <==
/*  BEGIN software license
 *
 *  msXpertSuite - mass spectrometry software suite
 *  -----------------------------------------------
 *  Copyright(C) 2009, 2017 Filippo Rusconi
 *
 *  http://www.msxpertsuite.org
 *
 *  This file is part of the msXpertSuite project.
 *
 *  The msXpertSuite project is the successor of the massXpert project. This
 *  project now includes various independent modules:
 *  
 *  - massXpert, model polymer chemistries and simulate mass spectrometric data;
 *  - mineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * END software license
*/



#ifndef MZ_LAB_MASS_BASED_ACTIONS_DLG_HPP
#define MZ_LAB_MASS_BASED_ACTIONS_DLG_HPP

// #pragma message("including MZ_LAB_MASS_BASED_ACTIONS_DLG_HPP")

/////////////////////// Qt includes


/////////////////////// Local includes
#include "ui_MzLabMassBasedActionsDlg.h"
#include "globals.hpp"
#include "MzLabWnd.hpp"

namespace msXpSmassXpert
{

  class MzLabMassBasedActionsDlg : public QDialog
  {
    Q_OBJECT

    private:
    Ui::MzLabMassBasedActionsDlg m_ui;

    QString m_configSettingsFilePath;

    MzLabWnd *mp_mzLabWnd;

    void closeEvent(QCloseEvent *event);

    public:
    MzLabMassBasedActionsDlg(QWidget *, const QString &configSettingsFilePath);

    ~MzLabMassBasedActionsDlg();

    private slots:
    void applyMassPushButton();
    void applyThresholdPushButton();
  };

} // namespace msXpSmassXpert


#endif // MZ_LAB_MASS_BASED_ACTIONS_DLG_HPP
// #pragma message("done...including MZ_LAB_MASS_BASED_ACTIONS_DLG_HPP")

==> msxpertsuite_4.1.0.orig.tar.gz: msxpertsuite-4.1.0/massxpert/gui/MzLabMassBasedActionsDlg.hpp <==
/*  BEGIN software license
 *
 *  msXpertSuite - mass spectrometry software suite
 *  -----------------------------------------------
 *  Copyright(C) 2009, 2017 Filippo Rusconi
 *
 *  http://www.msxpertsuite.org
 *
 *  This file is part of the msXpertSuite project.
 *
 *  The msXpertSuite project is the successor of the massXpert project. This
 *  project now includes various independent modules:
 *  
 *  - massXpert, model polymer chemistries and simulate mass spectrometric data;
 *  - mineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * END software license
*/



#ifndef MZ_LAB_MASS_BASED_ACTIONS_DLG_HPP
#define MZ_LAB_MASS_BASED_ACTIONS_DLG_HPP

// #pragma message("including MZ_LAB_MASS_BASED_ACTIONS_DLG_HPP")

/////////////////////// Qt includes


/////////////////////// Local includes
#include <ui_MzLabMassBasedActionsDlg.h>
#include <massxpert/nongui/globals.hpp>
#include <massxpert/gui/MzLabWnd.hpp>

namespace msXpSmassXpert
{

  class MzLabMassBasedActionsDlg : public QDialog
  {
    Q_OBJECT

    private:
    Ui::MzLabMassBasedActionsDlg m_ui;

    QString m_configSettingsFilePath;

    MzLabWnd *mp_mzLabWnd;

    void closeEvent(QCloseEvent *event);

    public:
    MzLabMassBasedActionsDlg(QWidget *, const QString &configSettingsFilePath);

    ~MzLabMassBasedActionsDlg();

    private slots:
    void applyMassPushButton();
    void applyThresholdPushButton();
  };

} // namespace msXpSmassXpert


#endif // MZ_LAB_MASS_BASED_ACTIONS_DLG_HPP
// #pragma message("done...including MZ_LAB_MASS_BASED_ACTIONS_DLG_HPP")
